@@ -3,7 +3,6 @@ from adrest.utils.auth import AnonimousAuthenticator
 from adrest.utils.emitter import XMLEmitter, JSONTemplateEmitter
 from adrest.views import ResourceView
 from adrest.resources.rpc import RPCResource
-from . import dummy
 
 
 class TestAuth(AnonimousAuthenticator):
@@ -43,5 +42,5 @@ API = Api(api_rpc=True, emitters=XMLEmitter)
 API.register(ChildResource)
 API.register(CustomResource, emitters=JSONTemplateEmitter)
 API.register(RootResource, authenticators=TestAuth)
-API.register(RPCResource, url_regex=r'^rpc2$', url_name='rpc2', scheme=dummy)
+API.register(RPCResource, url_regex=r'^rpc2$', url_name='rpc2', scheme='tests.rpc.dummy')
 API.register(TestResource)
